@@ -3,7 +3,7 @@ package CPANPLUS::Dist::Slackware::PackageDescription;
 use strict;
 use warnings;
 
-our $VERSION = '1.020';
+our $VERSION = '1.021';
 
 use English qw( -no_match_vars );
 
@@ -396,10 +396,11 @@ sub _prereqs {
 
             # Omit modules that are distributed with Perl.
             my $version = $prereq_ref->{$srcname};
-            {
+            my $s       = Module::CoreList->removed_from($srcname);
+            if ( !defined $s || $perl_version < version->parse($s) ) {
                 ## cpan2dist is run with -w, which triggers a warning in
                 ## Module::CoreList.
-                local ($WARNING) = 0;
+                local $WARNING = 0;
                 my $r = Module::CoreList->first_release( $srcname, $version );
                 next if defined $r && version->parse($r) <= $perl_version;
             }
@@ -488,7 +489,7 @@ CPANPLUS::Dist::Slackware::PackageDescription - Collect information on a package
 
 =head1 VERSION
 
-This document describes CPANPLUS::Dist::Slackware::PackageDescription version 1.020.
+This document describes CPANPLUS::Dist::Slackware::PackageDescription version 1.021.
 
 =head1 SYNOPSIS
 
@@ -673,7 +674,7 @@ through the web interface at L<http://rt.cpan.org/>.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012-2014 Andreas Voegele
+Copyright 2012-2015 Andreas Voegele
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
